from __future__ import absolute_import
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: TSTStylePropertyArchiving.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import TSPMessages_pb2 as TSPMessages__pb2
from . import TSDArchives_pb2 as TSDArchives__pb2
from . import TSKArchives_pb2 as TSKArchives__pb2
from . import TSSArchives_pb2 as TSSArchives__pb2
from . import TSWPArchives_pb2 as TSWPArchives__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='TSTStylePropertyArchiving.proto',
  package='TST',
  syntax='proto2',
  serialized_options=None,
  serialized_pb=_b('\n\x1fTSTStylePropertyArchiving.proto\x12\x03TST\x1a\x11TSPMessages.proto\x1a\x11TSDArchives.proto\x1a\x11TSKArchives.proto\x1a\x11TSSArchives.proto\x1a\x12TSWPArchives.proto\"\x83\x01\n\x1d\x44\x65precated_TableStrokeArchive\x12\"\n\x06stroke\x18\x01 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x16\n\nbackground\x18\x02 \x01(\x08\x42\x02\x18\x01\x12\x13\n\x07opacity\x18\x03 \x01(\x02\x42\x02\x18\x01\x12\x11\n\x05\x65mpty\x18\x04 \x01(\x08\x42\x02\x18\x01\"\xcf\x04\n\x1a\x43\x65llStylePropertiesArchive\x12#\n\tcell_fill\x18\x01 \x01(\x0b\x32\x10.TSD.FillArchive\x12\x11\n\ttext_wrap\x18\x03 \x01(\x08\x12\x41\n\x15\x64\x65precated_top_stroke\x18\x04 \x01(\x0b\x32\".TST.Deprecated_TableStrokeArchive\x12\x43\n\x17\x64\x65precated_right_stroke\x18\x05 \x01(\x0b\x32\".TST.Deprecated_TableStrokeArchive\x12\x44\n\x18\x64\x65precated_bottom_stroke\x18\x06 \x01(\x0b\x32\".TST.Deprecated_TableStrokeArchive\x12\x42\n\x16\x64\x65precated_left_stroke\x18\x07 \x01(\x0b\x32\".TST.Deprecated_TableStrokeArchive\x12\x1a\n\x12vertical_alignment\x18\x08 \x01(\x05\x12%\n\x07padding\x18\t \x01(\x0b\x32\x14.TSWP.PaddingArchive\x12&\n\ntop_stroke\x18\n \x01(\x0b\x32\x12.TSD.StrokeArchive\x12(\n\x0cright_stroke\x18\x0b \x01(\x0b\x32\x12.TSD.StrokeArchive\x12)\n\rbottom_stroke\x18\x0c \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\'\n\x0bleft_stroke\x18\r \x01(\x0b\x32\x12.TSD.StrokeArchive\"\x9f\x02\n\"Deprecated_StrokePresetDataArchive\x12H\n\x1c\x64\x65precated_horizontal_stroke\x18\x02 \x02(\x0b\x32\".TST.Deprecated_TableStrokeArchive\x12\x46\n\x1a\x64\x65precated_vertical_stroke\x18\x01 \x02(\x0b\x32\".TST.Deprecated_TableStrokeArchive\x12\x46\n\x1a\x64\x65precated_exterior_stroke\x18\x03 \x02(\x0b\x32\".TST.Deprecated_TableStrokeArchive\x12\x1f\n\x17\x64\x65precated_visible_mask\x18\x05 \x02(\x05\"\xb8\x01\n\x17StrokePresetDataArchive\x12-\n\x11horizontal_stroke\x18\x01 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12+\n\x0fvertical_stroke\x18\x02 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12+\n\x0f\x65xterior_stroke\x18\x03 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x14\n\x0cvisible_mask\x18\x04 \x01(\x05\"\x9a\x01\n\x17StrokePresetListArchive\x12\r\n\x05\x63ount\x18\x01 \x02(\x05\x12\x42\n\x11\x64\x65precated_preset\x18\x02 \x03(\x0b\x32\'.TST.Deprecated_StrokePresetDataArchive\x12,\n\x06preset\x18\x03 \x03(\x0b\x32\x1c.TST.StrokePresetDataArchive\"\xb7 \n\x1bTableStylePropertiesArchive\x12\x13\n\x0b\x62\x61nded_rows\x18\x01 \x01(\x08\x12%\n\x0b\x62\x61nded_fill\x18\x02 \x01(\x0b\x32\x10.TSD.FillArchive\x12 \n\x18\x62\x65haves_like_spreadsheet\x18\x15 \x01(\x08\x12\x13\n\x0b\x61uto_resize\x18\x16 \x01(\x08\x12R\n&deprecated_header_row_separator_stroke\x18\x04 \x01(\x0b\x32\".TST.Deprecated_TableStrokeArchive\x12O\n#deprecated_header_row_border_stroke\x18\x05 \x01(\x0b\x32\".TST.Deprecated_TableStrokeArchive\x12S\n\'deprecated_header_row_horizontal_stroke\x18\x17 \x01(\x0b\x32\".TST.Deprecated_TableStrokeArchive\x12Q\n%deprecated_header_row_vertical_stroke\x18\x18 \x01(\x0b\x32\".TST.Deprecated_TableStrokeArchive\x12R\n&deprecated_header_column_border_stroke\x18\x07 \x01(\x0b\x32\".TST.Deprecated_TableStrokeArchive\x12U\n)deprecated_header_column_separator_stroke\x18\x08 \x01(\x0b\x32\".TST.Deprecated_TableStrokeArchive\x12V\n*deprecated_header_column_horizontal_stroke\x18\x19 \x01(\x0b\x32\".TST.Deprecated_TableStrokeArchive\x12T\n(deprecated_header_column_vertical_stroke\x18\x1a \x01(\x0b\x32\".TST.Deprecated_TableStrokeArchive\x12R\n&deprecated_footer_row_separator_stroke\x18\n \x01(\x0b\x32\".TST.Deprecated_TableStrokeArchive\x12O\n#deprecated_footer_row_border_stroke\x18\x0b \x01(\x0b\x32\".TST.Deprecated_TableStrokeArchive\x12S\n\'deprecated_footer_row_horizontal_stroke\x18\x1b \x01(\x0b\x32\".TST.Deprecated_TableStrokeArchive\x12Q\n%deprecated_footer_row_vertical_stroke\x18\x1c \x01(\x0b\x32\".TST.Deprecated_TableStrokeArchive\x12Z\n.deprecated_table_body_horizontal_border_stroke\x18\x0c \x01(\x0b\x32\".TST.Deprecated_TableStrokeArchive\x12X\n,deprecated_table_body_vertical_border_stroke\x18\x1d \x01(\x0b\x32\".TST.Deprecated_TableStrokeArchive\x12S\n\'deprecated_table_body_horizontal_stroke\x18\x1e \x01(\x0b\x32\".TST.Deprecated_TableStrokeArchive\x12Q\n%deprecated_table_body_vertical_stroke\x18\x1f \x01(\x0b\x32\".TST.Deprecated_TableStrokeArchive\x12\x38\n\x12stroke_preset_list\x18  \x01(\x0b\x32\x1c.TST.StrokePresetListArchive\x12\x19\n\x11v_strokes_visible\x18! \x01(\x08\x12\x19\n\x11h_strokes_visible\x18\" \x01(\x08\x12\x1c\n\x14hr_separator_visible\x18# \x01(\x08\x12\x1c\n\x14hc_separator_visible\x18$ \x01(\x08\x12 \n\x18\x66ooter_separator_visible\x18% \x01(\x08\x12\x1c\n\x14table_border_visible\x18& \x01(\x08\x12#\n\x1btable_header_border_visible\x18\' \x01(\x08\x12 \n\x18table_hc_divider_visible\x18* \x01(\x08\x12 \n\x18table_hr_divider_visible\x18+ \x01(\x08\x12$\n\x1ctable_footer_divider_visible\x18, \x01(\x08\x12!\n\x19OBSOLETE_master_font_size\x18( \x01(\x05\x12\x1a\n\x12master_font_family\x18) \x01(\t\x12\x35\n\x11writing_direction\x18- \x01(\x0e\x32\x1a.TSWP.WritingDirectionType\x12\x37\n\x1bheader_row_separator_stroke\x18. \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x34\n\x18header_row_border_stroke\x18/ \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x38\n\x1cheader_row_horizontal_stroke\x18\x30 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x36\n\x1aheader_row_vertical_stroke\x18\x31 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x37\n\x1bheader_column_border_stroke\x18\x32 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12:\n\x1eheader_column_separator_stroke\x18\x33 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12;\n\x1fheader_column_horizontal_stroke\x18\x34 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x39\n\x1dheader_column_vertical_stroke\x18\x35 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x37\n\x1b\x66ooter_row_separator_stroke\x18\x36 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x34\n\x18\x66ooter_row_border_stroke\x18\x37 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x38\n\x1c\x66ooter_row_horizontal_stroke\x18\x38 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x36\n\x1a\x66ooter_row_vertical_stroke\x18\x39 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12?\n#table_body_horizontal_border_stroke\x18: \x01(\x0b\x32\x12.TSD.StrokeArchive\x12=\n!table_body_vertical_border_stroke\x18; \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x38\n\x1ctable_body_horizontal_stroke\x18< \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x36\n\x1atable_body_vertical_stroke\x18= \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x36\n\x1a\x63\x61tegory_level1_top_stroke\x18> \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x36\n\x1a\x63\x61tegory_level2_top_stroke\x18? \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x36\n\x1a\x63\x61tegory_level3_top_stroke\x18@ \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x36\n\x1a\x63\x61tegory_level4_top_stroke\x18\x41 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x36\n\x1a\x63\x61tegory_level5_top_stroke\x18\x42 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x39\n\x1d\x63\x61tegory_level1_bottom_stroke\x18\x43 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x39\n\x1d\x63\x61tegory_level2_bottom_stroke\x18\x44 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x39\n\x1d\x63\x61tegory_level3_bottom_stroke\x18\x45 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x39\n\x1d\x63\x61tegory_level4_bottom_stroke\x18\x46 \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x39\n\x1d\x63\x61tegory_level5_bottom_stroke\x18G \x01(\x0b\x32\x12.TSD.StrokeArchive\x12;\n\x1f\x63\x61tegory_level1_interior_stroke\x18H \x01(\x0b\x32\x12.TSD.StrokeArchive\x12;\n\x1f\x63\x61tegory_level2_interior_stroke\x18I \x01(\x0b\x32\x12.TSD.StrokeArchive\x12;\n\x1f\x63\x61tegory_level3_interior_stroke\x18J \x01(\x0b\x32\x12.TSD.StrokeArchive\x12;\n\x1f\x63\x61tegory_level4_interior_stroke\x18K \x01(\x0b\x32\x12.TSD.StrokeArchive\x12;\n\x1f\x63\x61tegory_level5_interior_stroke\x18L \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x42\n&category_level1_label_separator_stroke\x18M \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x42\n&category_level2_label_separator_stroke\x18N \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x42\n&category_level3_label_separator_stroke\x18O \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x42\n&category_level4_label_separator_stroke\x18P \x01(\x0b\x32\x12.TSD.StrokeArchive\x12\x42\n&category_level5_label_separator_stroke\x18Q \x01(\x0b\x32\x12.TSD.StrokeArchive\"n\n\x17TableStylePresetArchive\x12\r\n\x05index\x18\x01 \x01(\x05\x12\x1d\n\x05image\x18\x02 \x01(\x0b\x32\x0e.TSP.Reference\x12%\n\rstyle_network\x18\x03 \x01(\x0b\x32\x0e.TSP.Reference\")\n\x18TableStrokePresetArchive\x12\r\n\x05index\x18\x01 \x02(\x05\"\xb6\x01\n\x13ThemePresetsArchive\x12+\n\x13table_style_presets\x18\x01 \x03(\x0b\x32\x0e.TSP.Reference\x12\x31\n\x19table_cell_stroke_presets\x18\x02 \x03(\x0b\x32\x0e.TSP.Reference2?\n\textension\x12\x11.TSS.ThemeArchive\x18\xc8\x01 \x01(\x0b\x32\x18.TST.ThemePresetsArchive')
  ,
  dependencies=[TSPMessages__pb2.DESCRIPTOR,TSDArchives__pb2.DESCRIPTOR,TSKArchives__pb2.DESCRIPTOR,TSSArchives__pb2.DESCRIPTOR,TSWPArchives__pb2.DESCRIPTOR,])




_DEPRECATED_TABLESTROKEARCHIVE = _descriptor.Descriptor(
  name='Deprecated_TableStrokeArchive',
  full_name='TST.Deprecated_TableStrokeArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stroke', full_name='TST.Deprecated_TableStrokeArchive.stroke', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='background', full_name='TST.Deprecated_TableStrokeArchive.background', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='opacity', full_name='TST.Deprecated_TableStrokeArchive.opacity', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='empty', full_name='TST.Deprecated_TableStrokeArchive.empty', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\030\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=137,
  serialized_end=268,
)


_CELLSTYLEPROPERTIESARCHIVE = _descriptor.Descriptor(
  name='CellStylePropertiesArchive',
  full_name='TST.CellStylePropertiesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cell_fill', full_name='TST.CellStylePropertiesArchive.cell_fill', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_wrap', full_name='TST.CellStylePropertiesArchive.text_wrap', index=1,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_top_stroke', full_name='TST.CellStylePropertiesArchive.deprecated_top_stroke', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_right_stroke', full_name='TST.CellStylePropertiesArchive.deprecated_right_stroke', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_bottom_stroke', full_name='TST.CellStylePropertiesArchive.deprecated_bottom_stroke', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_left_stroke', full_name='TST.CellStylePropertiesArchive.deprecated_left_stroke', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vertical_alignment', full_name='TST.CellStylePropertiesArchive.vertical_alignment', index=6,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='padding', full_name='TST.CellStylePropertiesArchive.padding', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='top_stroke', full_name='TST.CellStylePropertiesArchive.top_stroke', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='right_stroke', full_name='TST.CellStylePropertiesArchive.right_stroke', index=9,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bottom_stroke', full_name='TST.CellStylePropertiesArchive.bottom_stroke', index=10,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='left_stroke', full_name='TST.CellStylePropertiesArchive.left_stroke', index=11,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=271,
  serialized_end=862,
)


_DEPRECATED_STROKEPRESETDATAARCHIVE = _descriptor.Descriptor(
  name='Deprecated_StrokePresetDataArchive',
  full_name='TST.Deprecated_StrokePresetDataArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='deprecated_horizontal_stroke', full_name='TST.Deprecated_StrokePresetDataArchive.deprecated_horizontal_stroke', index=0,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_vertical_stroke', full_name='TST.Deprecated_StrokePresetDataArchive.deprecated_vertical_stroke', index=1,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_exterior_stroke', full_name='TST.Deprecated_StrokePresetDataArchive.deprecated_exterior_stroke', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_visible_mask', full_name='TST.Deprecated_StrokePresetDataArchive.deprecated_visible_mask', index=3,
      number=5, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=865,
  serialized_end=1152,
)


_STROKEPRESETDATAARCHIVE = _descriptor.Descriptor(
  name='StrokePresetDataArchive',
  full_name='TST.StrokePresetDataArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='horizontal_stroke', full_name='TST.StrokePresetDataArchive.horizontal_stroke', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vertical_stroke', full_name='TST.StrokePresetDataArchive.vertical_stroke', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exterior_stroke', full_name='TST.StrokePresetDataArchive.exterior_stroke', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='visible_mask', full_name='TST.StrokePresetDataArchive.visible_mask', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1155,
  serialized_end=1339,
)


_STROKEPRESETLISTARCHIVE = _descriptor.Descriptor(
  name='StrokePresetListArchive',
  full_name='TST.StrokePresetListArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='TST.StrokePresetListArchive.count', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_preset', full_name='TST.StrokePresetListArchive.deprecated_preset', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='preset', full_name='TST.StrokePresetListArchive.preset', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1342,
  serialized_end=1496,
)


_TABLESTYLEPROPERTIESARCHIVE = _descriptor.Descriptor(
  name='TableStylePropertiesArchive',
  full_name='TST.TableStylePropertiesArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='banded_rows', full_name='TST.TableStylePropertiesArchive.banded_rows', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='banded_fill', full_name='TST.TableStylePropertiesArchive.banded_fill', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='behaves_like_spreadsheet', full_name='TST.TableStylePropertiesArchive.behaves_like_spreadsheet', index=2,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='auto_resize', full_name='TST.TableStylePropertiesArchive.auto_resize', index=3,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_header_row_separator_stroke', full_name='TST.TableStylePropertiesArchive.deprecated_header_row_separator_stroke', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_header_row_border_stroke', full_name='TST.TableStylePropertiesArchive.deprecated_header_row_border_stroke', index=5,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_header_row_horizontal_stroke', full_name='TST.TableStylePropertiesArchive.deprecated_header_row_horizontal_stroke', index=6,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_header_row_vertical_stroke', full_name='TST.TableStylePropertiesArchive.deprecated_header_row_vertical_stroke', index=7,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_header_column_border_stroke', full_name='TST.TableStylePropertiesArchive.deprecated_header_column_border_stroke', index=8,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_header_column_separator_stroke', full_name='TST.TableStylePropertiesArchive.deprecated_header_column_separator_stroke', index=9,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_header_column_horizontal_stroke', full_name='TST.TableStylePropertiesArchive.deprecated_header_column_horizontal_stroke', index=10,
      number=25, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_header_column_vertical_stroke', full_name='TST.TableStylePropertiesArchive.deprecated_header_column_vertical_stroke', index=11,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_footer_row_separator_stroke', full_name='TST.TableStylePropertiesArchive.deprecated_footer_row_separator_stroke', index=12,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_footer_row_border_stroke', full_name='TST.TableStylePropertiesArchive.deprecated_footer_row_border_stroke', index=13,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_footer_row_horizontal_stroke', full_name='TST.TableStylePropertiesArchive.deprecated_footer_row_horizontal_stroke', index=14,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_footer_row_vertical_stroke', full_name='TST.TableStylePropertiesArchive.deprecated_footer_row_vertical_stroke', index=15,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_table_body_horizontal_border_stroke', full_name='TST.TableStylePropertiesArchive.deprecated_table_body_horizontal_border_stroke', index=16,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_table_body_vertical_border_stroke', full_name='TST.TableStylePropertiesArchive.deprecated_table_body_vertical_border_stroke', index=17,
      number=29, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_table_body_horizontal_stroke', full_name='TST.TableStylePropertiesArchive.deprecated_table_body_horizontal_stroke', index=18,
      number=30, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated_table_body_vertical_stroke', full_name='TST.TableStylePropertiesArchive.deprecated_table_body_vertical_stroke', index=19,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stroke_preset_list', full_name='TST.TableStylePropertiesArchive.stroke_preset_list', index=20,
      number=32, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='v_strokes_visible', full_name='TST.TableStylePropertiesArchive.v_strokes_visible', index=21,
      number=33, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='h_strokes_visible', full_name='TST.TableStylePropertiesArchive.h_strokes_visible', index=22,
      number=34, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hr_separator_visible', full_name='TST.TableStylePropertiesArchive.hr_separator_visible', index=23,
      number=35, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hc_separator_visible', full_name='TST.TableStylePropertiesArchive.hc_separator_visible', index=24,
      number=36, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='footer_separator_visible', full_name='TST.TableStylePropertiesArchive.footer_separator_visible', index=25,
      number=37, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_border_visible', full_name='TST.TableStylePropertiesArchive.table_border_visible', index=26,
      number=38, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_header_border_visible', full_name='TST.TableStylePropertiesArchive.table_header_border_visible', index=27,
      number=39, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_hc_divider_visible', full_name='TST.TableStylePropertiesArchive.table_hc_divider_visible', index=28,
      number=42, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_hr_divider_visible', full_name='TST.TableStylePropertiesArchive.table_hr_divider_visible', index=29,
      number=43, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_footer_divider_visible', full_name='TST.TableStylePropertiesArchive.table_footer_divider_visible', index=30,
      number=44, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='OBSOLETE_master_font_size', full_name='TST.TableStylePropertiesArchive.OBSOLETE_master_font_size', index=31,
      number=40, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='master_font_family', full_name='TST.TableStylePropertiesArchive.master_font_family', index=32,
      number=41, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='writing_direction', full_name='TST.TableStylePropertiesArchive.writing_direction', index=33,
      number=45, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_row_separator_stroke', full_name='TST.TableStylePropertiesArchive.header_row_separator_stroke', index=34,
      number=46, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_row_border_stroke', full_name='TST.TableStylePropertiesArchive.header_row_border_stroke', index=35,
      number=47, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_row_horizontal_stroke', full_name='TST.TableStylePropertiesArchive.header_row_horizontal_stroke', index=36,
      number=48, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_row_vertical_stroke', full_name='TST.TableStylePropertiesArchive.header_row_vertical_stroke', index=37,
      number=49, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_column_border_stroke', full_name='TST.TableStylePropertiesArchive.header_column_border_stroke', index=38,
      number=50, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_column_separator_stroke', full_name='TST.TableStylePropertiesArchive.header_column_separator_stroke', index=39,
      number=51, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_column_horizontal_stroke', full_name='TST.TableStylePropertiesArchive.header_column_horizontal_stroke', index=40,
      number=52, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='header_column_vertical_stroke', full_name='TST.TableStylePropertiesArchive.header_column_vertical_stroke', index=41,
      number=53, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='footer_row_separator_stroke', full_name='TST.TableStylePropertiesArchive.footer_row_separator_stroke', index=42,
      number=54, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='footer_row_border_stroke', full_name='TST.TableStylePropertiesArchive.footer_row_border_stroke', index=43,
      number=55, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='footer_row_horizontal_stroke', full_name='TST.TableStylePropertiesArchive.footer_row_horizontal_stroke', index=44,
      number=56, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='footer_row_vertical_stroke', full_name='TST.TableStylePropertiesArchive.footer_row_vertical_stroke', index=45,
      number=57, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_body_horizontal_border_stroke', full_name='TST.TableStylePropertiesArchive.table_body_horizontal_border_stroke', index=46,
      number=58, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_body_vertical_border_stroke', full_name='TST.TableStylePropertiesArchive.table_body_vertical_border_stroke', index=47,
      number=59, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_body_horizontal_stroke', full_name='TST.TableStylePropertiesArchive.table_body_horizontal_stroke', index=48,
      number=60, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_body_vertical_stroke', full_name='TST.TableStylePropertiesArchive.table_body_vertical_stroke', index=49,
      number=61, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level1_top_stroke', full_name='TST.TableStylePropertiesArchive.category_level1_top_stroke', index=50,
      number=62, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level2_top_stroke', full_name='TST.TableStylePropertiesArchive.category_level2_top_stroke', index=51,
      number=63, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level3_top_stroke', full_name='TST.TableStylePropertiesArchive.category_level3_top_stroke', index=52,
      number=64, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level4_top_stroke', full_name='TST.TableStylePropertiesArchive.category_level4_top_stroke', index=53,
      number=65, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level5_top_stroke', full_name='TST.TableStylePropertiesArchive.category_level5_top_stroke', index=54,
      number=66, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level1_bottom_stroke', full_name='TST.TableStylePropertiesArchive.category_level1_bottom_stroke', index=55,
      number=67, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level2_bottom_stroke', full_name='TST.TableStylePropertiesArchive.category_level2_bottom_stroke', index=56,
      number=68, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level3_bottom_stroke', full_name='TST.TableStylePropertiesArchive.category_level3_bottom_stroke', index=57,
      number=69, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level4_bottom_stroke', full_name='TST.TableStylePropertiesArchive.category_level4_bottom_stroke', index=58,
      number=70, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level5_bottom_stroke', full_name='TST.TableStylePropertiesArchive.category_level5_bottom_stroke', index=59,
      number=71, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level1_interior_stroke', full_name='TST.TableStylePropertiesArchive.category_level1_interior_stroke', index=60,
      number=72, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level2_interior_stroke', full_name='TST.TableStylePropertiesArchive.category_level2_interior_stroke', index=61,
      number=73, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level3_interior_stroke', full_name='TST.TableStylePropertiesArchive.category_level3_interior_stroke', index=62,
      number=74, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level4_interior_stroke', full_name='TST.TableStylePropertiesArchive.category_level4_interior_stroke', index=63,
      number=75, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level5_interior_stroke', full_name='TST.TableStylePropertiesArchive.category_level5_interior_stroke', index=64,
      number=76, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level1_label_separator_stroke', full_name='TST.TableStylePropertiesArchive.category_level1_label_separator_stroke', index=65,
      number=77, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level2_label_separator_stroke', full_name='TST.TableStylePropertiesArchive.category_level2_label_separator_stroke', index=66,
      number=78, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level3_label_separator_stroke', full_name='TST.TableStylePropertiesArchive.category_level3_label_separator_stroke', index=67,
      number=79, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level4_label_separator_stroke', full_name='TST.TableStylePropertiesArchive.category_level4_label_separator_stroke', index=68,
      number=80, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='category_level5_label_separator_stroke', full_name='TST.TableStylePropertiesArchive.category_level5_label_separator_stroke', index=69,
      number=81, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1499,
  serialized_end=5650,
)


_TABLESTYLEPRESETARCHIVE = _descriptor.Descriptor(
  name='TableStylePresetArchive',
  full_name='TST.TableStylePresetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='TST.TableStylePresetArchive.index', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image', full_name='TST.TableStylePresetArchive.image', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='style_network', full_name='TST.TableStylePresetArchive.style_network', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5652,
  serialized_end=5762,
)


_TABLESTROKEPRESETARCHIVE = _descriptor.Descriptor(
  name='TableStrokePresetArchive',
  full_name='TST.TableStrokePresetArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='TST.TableStrokePresetArchive.index', index=0,
      number=1, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5764,
  serialized_end=5805,
)


_THEMEPRESETSARCHIVE = _descriptor.Descriptor(
  name='ThemePresetsArchive',
  full_name='TST.ThemePresetsArchive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='table_style_presets', full_name='TST.ThemePresetsArchive.table_style_presets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table_cell_stroke_presets', full_name='TST.ThemePresetsArchive.table_cell_stroke_presets', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
    _descriptor.FieldDescriptor(
      name='extension', full_name='TST.ThemePresetsArchive.extension', index=0,
      number=200, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=True, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5808,
  serialized_end=5990,
)

_DEPRECATED_TABLESTROKEARCHIVE.fields_by_name['stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CELLSTYLEPROPERTIESARCHIVE.fields_by_name['cell_fill'].message_type = TSDArchives__pb2._FILLARCHIVE
_CELLSTYLEPROPERTIESARCHIVE.fields_by_name['deprecated_top_stroke'].message_type = _DEPRECATED_TABLESTROKEARCHIVE
_CELLSTYLEPROPERTIESARCHIVE.fields_by_name['deprecated_right_stroke'].message_type = _DEPRECATED_TABLESTROKEARCHIVE
_CELLSTYLEPROPERTIESARCHIVE.fields_by_name['deprecated_bottom_stroke'].message_type = _DEPRECATED_TABLESTROKEARCHIVE
_CELLSTYLEPROPERTIESARCHIVE.fields_by_name['deprecated_left_stroke'].message_type = _DEPRECATED_TABLESTROKEARCHIVE
_CELLSTYLEPROPERTIESARCHIVE.fields_by_name['padding'].message_type = TSWPArchives__pb2._PADDINGARCHIVE
_CELLSTYLEPROPERTIESARCHIVE.fields_by_name['top_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CELLSTYLEPROPERTIESARCHIVE.fields_by_name['right_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CELLSTYLEPROPERTIESARCHIVE.fields_by_name['bottom_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_CELLSTYLEPROPERTIESARCHIVE.fields_by_name['left_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_DEPRECATED_STROKEPRESETDATAARCHIVE.fields_by_name['deprecated_horizontal_stroke'].message_type = _DEPRECATED_TABLESTROKEARCHIVE
_DEPRECATED_STROKEPRESETDATAARCHIVE.fields_by_name['deprecated_vertical_stroke'].message_type = _DEPRECATED_TABLESTROKEARCHIVE
_DEPRECATED_STROKEPRESETDATAARCHIVE.fields_by_name['deprecated_exterior_stroke'].message_type = _DEPRECATED_TABLESTROKEARCHIVE
_STROKEPRESETDATAARCHIVE.fields_by_name['horizontal_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_STROKEPRESETDATAARCHIVE.fields_by_name['vertical_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_STROKEPRESETDATAARCHIVE.fields_by_name['exterior_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_STROKEPRESETLISTARCHIVE.fields_by_name['deprecated_preset'].message_type = _DEPRECATED_STROKEPRESETDATAARCHIVE
_STROKEPRESETLISTARCHIVE.fields_by_name['preset'].message_type = _STROKEPRESETDATAARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['banded_fill'].message_type = TSDArchives__pb2._FILLARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['deprecated_header_row_separator_stroke'].message_type = _DEPRECATED_TABLESTROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['deprecated_header_row_border_stroke'].message_type = _DEPRECATED_TABLESTROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['deprecated_header_row_horizontal_stroke'].message_type = _DEPRECATED_TABLESTROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['deprecated_header_row_vertical_stroke'].message_type = _DEPRECATED_TABLESTROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['deprecated_header_column_border_stroke'].message_type = _DEPRECATED_TABLESTROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['deprecated_header_column_separator_stroke'].message_type = _DEPRECATED_TABLESTROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['deprecated_header_column_horizontal_stroke'].message_type = _DEPRECATED_TABLESTROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['deprecated_header_column_vertical_stroke'].message_type = _DEPRECATED_TABLESTROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['deprecated_footer_row_separator_stroke'].message_type = _DEPRECATED_TABLESTROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['deprecated_footer_row_border_stroke'].message_type = _DEPRECATED_TABLESTROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['deprecated_footer_row_horizontal_stroke'].message_type = _DEPRECATED_TABLESTROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['deprecated_footer_row_vertical_stroke'].message_type = _DEPRECATED_TABLESTROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['deprecated_table_body_horizontal_border_stroke'].message_type = _DEPRECATED_TABLESTROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['deprecated_table_body_vertical_border_stroke'].message_type = _DEPRECATED_TABLESTROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['deprecated_table_body_horizontal_stroke'].message_type = _DEPRECATED_TABLESTROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['deprecated_table_body_vertical_stroke'].message_type = _DEPRECATED_TABLESTROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['stroke_preset_list'].message_type = _STROKEPRESETLISTARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['writing_direction'].enum_type = TSWPArchives__pb2._WRITINGDIRECTIONTYPE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['header_row_separator_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['header_row_border_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['header_row_horizontal_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['header_row_vertical_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['header_column_border_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['header_column_separator_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['header_column_horizontal_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['header_column_vertical_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['footer_row_separator_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['footer_row_border_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['footer_row_horizontal_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['footer_row_vertical_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['table_body_horizontal_border_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['table_body_vertical_border_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['table_body_horizontal_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['table_body_vertical_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['category_level1_top_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['category_level2_top_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['category_level3_top_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['category_level4_top_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['category_level5_top_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['category_level1_bottom_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['category_level2_bottom_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['category_level3_bottom_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['category_level4_bottom_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['category_level5_bottom_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['category_level1_interior_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['category_level2_interior_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['category_level3_interior_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['category_level4_interior_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['category_level5_interior_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['category_level1_label_separator_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['category_level2_label_separator_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['category_level3_label_separator_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['category_level4_label_separator_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_TABLESTYLEPROPERTIESARCHIVE.fields_by_name['category_level5_label_separator_stroke'].message_type = TSDArchives__pb2._STROKEARCHIVE
_TABLESTYLEPRESETARCHIVE.fields_by_name['image'].message_type = TSPMessages__pb2._REFERENCE
_TABLESTYLEPRESETARCHIVE.fields_by_name['style_network'].message_type = TSPMessages__pb2._REFERENCE
_THEMEPRESETSARCHIVE.fields_by_name['table_style_presets'].message_type = TSPMessages__pb2._REFERENCE
_THEMEPRESETSARCHIVE.fields_by_name['table_cell_stroke_presets'].message_type = TSPMessages__pb2._REFERENCE
DESCRIPTOR.message_types_by_name['Deprecated_TableStrokeArchive'] = _DEPRECATED_TABLESTROKEARCHIVE
DESCRIPTOR.message_types_by_name['CellStylePropertiesArchive'] = _CELLSTYLEPROPERTIESARCHIVE
DESCRIPTOR.message_types_by_name['Deprecated_StrokePresetDataArchive'] = _DEPRECATED_STROKEPRESETDATAARCHIVE
DESCRIPTOR.message_types_by_name['StrokePresetDataArchive'] = _STROKEPRESETDATAARCHIVE
DESCRIPTOR.message_types_by_name['StrokePresetListArchive'] = _STROKEPRESETLISTARCHIVE
DESCRIPTOR.message_types_by_name['TableStylePropertiesArchive'] = _TABLESTYLEPROPERTIESARCHIVE
DESCRIPTOR.message_types_by_name['TableStylePresetArchive'] = _TABLESTYLEPRESETARCHIVE
DESCRIPTOR.message_types_by_name['TableStrokePresetArchive'] = _TABLESTROKEPRESETARCHIVE
DESCRIPTOR.message_types_by_name['ThemePresetsArchive'] = _THEMEPRESETSARCHIVE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Deprecated_TableStrokeArchive = _reflection.GeneratedProtocolMessageType('Deprecated_TableStrokeArchive', (_message.Message,), dict(
  DESCRIPTOR = _DEPRECATED_TABLESTROKEARCHIVE,
  __module__ = 'TSTStylePropertyArchiving_pb2'
  # @@protoc_insertion_point(class_scope:TST.Deprecated_TableStrokeArchive)
  ))
_sym_db.RegisterMessage(Deprecated_TableStrokeArchive)

CellStylePropertiesArchive = _reflection.GeneratedProtocolMessageType('CellStylePropertiesArchive', (_message.Message,), dict(
  DESCRIPTOR = _CELLSTYLEPROPERTIESARCHIVE,
  __module__ = 'TSTStylePropertyArchiving_pb2'
  # @@protoc_insertion_point(class_scope:TST.CellStylePropertiesArchive)
  ))
_sym_db.RegisterMessage(CellStylePropertiesArchive)

Deprecated_StrokePresetDataArchive = _reflection.GeneratedProtocolMessageType('Deprecated_StrokePresetDataArchive', (_message.Message,), dict(
  DESCRIPTOR = _DEPRECATED_STROKEPRESETDATAARCHIVE,
  __module__ = 'TSTStylePropertyArchiving_pb2'
  # @@protoc_insertion_point(class_scope:TST.Deprecated_StrokePresetDataArchive)
  ))
_sym_db.RegisterMessage(Deprecated_StrokePresetDataArchive)

StrokePresetDataArchive = _reflection.GeneratedProtocolMessageType('StrokePresetDataArchive', (_message.Message,), dict(
  DESCRIPTOR = _STROKEPRESETDATAARCHIVE,
  __module__ = 'TSTStylePropertyArchiving_pb2'
  # @@protoc_insertion_point(class_scope:TST.StrokePresetDataArchive)
  ))
_sym_db.RegisterMessage(StrokePresetDataArchive)

StrokePresetListArchive = _reflection.GeneratedProtocolMessageType('StrokePresetListArchive', (_message.Message,), dict(
  DESCRIPTOR = _STROKEPRESETLISTARCHIVE,
  __module__ = 'TSTStylePropertyArchiving_pb2'
  # @@protoc_insertion_point(class_scope:TST.StrokePresetListArchive)
  ))
_sym_db.RegisterMessage(StrokePresetListArchive)

TableStylePropertiesArchive = _reflection.GeneratedProtocolMessageType('TableStylePropertiesArchive', (_message.Message,), dict(
  DESCRIPTOR = _TABLESTYLEPROPERTIESARCHIVE,
  __module__ = 'TSTStylePropertyArchiving_pb2'
  # @@protoc_insertion_point(class_scope:TST.TableStylePropertiesArchive)
  ))
_sym_db.RegisterMessage(TableStylePropertiesArchive)

TableStylePresetArchive = _reflection.GeneratedProtocolMessageType('TableStylePresetArchive', (_message.Message,), dict(
  DESCRIPTOR = _TABLESTYLEPRESETARCHIVE,
  __module__ = 'TSTStylePropertyArchiving_pb2'
  # @@protoc_insertion_point(class_scope:TST.TableStylePresetArchive)
  ))
_sym_db.RegisterMessage(TableStylePresetArchive)

TableStrokePresetArchive = _reflection.GeneratedProtocolMessageType('TableStrokePresetArchive', (_message.Message,), dict(
  DESCRIPTOR = _TABLESTROKEPRESETARCHIVE,
  __module__ = 'TSTStylePropertyArchiving_pb2'
  # @@protoc_insertion_point(class_scope:TST.TableStrokePresetArchive)
  ))
_sym_db.RegisterMessage(TableStrokePresetArchive)

ThemePresetsArchive = _reflection.GeneratedProtocolMessageType('ThemePresetsArchive', (_message.Message,), dict(
  DESCRIPTOR = _THEMEPRESETSARCHIVE,
  __module__ = 'TSTStylePropertyArchiving_pb2'
  # @@protoc_insertion_point(class_scope:TST.ThemePresetsArchive)
  ))
_sym_db.RegisterMessage(ThemePresetsArchive)

_THEMEPRESETSARCHIVE.extensions_by_name['extension'].message_type = _THEMEPRESETSARCHIVE
TSSArchives__pb2.ThemeArchive.RegisterExtension(_THEMEPRESETSARCHIVE.extensions_by_name['extension'])

_DEPRECATED_TABLESTROKEARCHIVE.fields_by_name['background']._options = None
_DEPRECATED_TABLESTROKEARCHIVE.fields_by_name['opacity']._options = None
_DEPRECATED_TABLESTROKEARCHIVE.fields_by_name['empty']._options = None
# @@protoc_insertion_point(module_scope)
